pub struct OrQuery<A, B>(pub A, pub B);Expand description
Union of two subqueries
This is equivalent to performing the two sub-queries and performing a boolean or on the results.
Tuple Fields
0: A1: BTrait Implementations
Sourceimpl<T: TreeTypes, A: Query<T>, B: Query<T>> Query<T> for OrQuery<A, B>
impl<T: TreeTypes, A: Query<T>, B: Query<T>> Query<T> for OrQuery<A, B>
Sourcefn containing(&self, offset: u64, index: &LeafIndex<T>, res: &mut [bool])
fn containing(&self, offset: u64, index: &LeafIndex<T>, res: &mut [bool])
a bitvec with
x.data.count() elements, where each value is a bool indicating if the query does matchSourcefn intersecting(&self, offset: u64, index: &BranchIndex<T>, res: &mut [bool])
fn intersecting(&self, offset: u64, index: &BranchIndex<T>, res: &mut [bool])
a bitvec with
x.data.count() elements, where each value is a bool indicating if the query can matchAuto Trait Implementations
impl<A, B> Freeze for OrQuery<A, B>
impl<A, B> RefUnwindSafe for OrQuery<A, B>where
A: RefUnwindSafe,
B: RefUnwindSafe,
impl<A, B> Send for OrQuery<A, B>
impl<A, B> Sync for OrQuery<A, B>
impl<A, B> Unpin for OrQuery<A, B>
impl<A, B> UnwindSafe for OrQuery<A, B>where
A: UnwindSafe,
B: UnwindSafe,